==> hasktags-0.71.2-31-x86_64.pkg.tar.xz: usr/share/haskell/register/hasktags.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasktags
version: 0.71.2
id: hasktags-0.71.2-8BxZbQrgX41LjyOz3kt88E
key: hasktags-0.71.2-8BxZbQrgX41LjyOz3kt88E
license: BSD-3-Clause
copyright: The University Court of the University of Glasgow
maintainer: Jack Henahan <jhenahan@me.com>,
            Marc Weber <marco-oweber@gmx.de>,
            Marco Túlio Pimenta Gontijo <marcotmarcot@gmail.com>
author: The GHC Team
homepage: http://github.com/MarcWeber/hasktags
synopsis: Produces ctags "tags" and etags "TAGS" files for Haskell programs
description:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs.
category: Development
abi: d6df882e98b22647b28c15ee9c4103ef
exposed: True
exposed-modules:
    Hasktags
hidden-modules: Tags DebugShow
import-dirs: /usr/lib/ghc-8.6.5/site-local/hasktags-0.71.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hasktags-0.71.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hasktags-0.71.2
hs-libraries: HShasktags-0.71.2-8BxZbQrgX41LjyOz3kt88E
depends:
    base-4.12.0.0 bytestring-0.10.8.2 directory-1.3.3.0
    filepath-1.4.2.1 json-0.9.3-GMBm0GlRjL45CY2W2ruX29
    microlens-platform-0.3.11-1TmwIay6JHVCCd7PBvKJ2b
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/hasktags/html/hasktags.haddock
haddock-html: /usr/share/doc/hasktags/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hasktags-0.71.2-33-x86_64.pkg.tar.xz: usr/share/haskell/register/hasktags.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasktags
version: 0.71.2
id: hasktags-0.71.2-1gORn2EhZbaCrvadY9CSJo
key: hasktags-0.71.2-1gORn2EhZbaCrvadY9CSJo
license: BSD-3-Clause
copyright: The University Court of the University of Glasgow
maintainer: Jack Henahan <jhenahan@me.com>,
            Marc Weber <marco-oweber@gmx.de>,
            Marco Túlio Pimenta Gontijo <marcotmarcot@gmail.com>
author: The GHC Team
homepage: http://github.com/MarcWeber/hasktags
synopsis: Produces ctags "tags" and etags "TAGS" files for Haskell programs
description:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs.
category: Development
abi: 0d8aef98222f202afbf5c8c925edc504
exposed: True
exposed-modules:
    Hasktags
hidden-modules: Tags DebugShow
import-dirs: /usr/lib/ghc-8.6.5/site-local/hasktags-0.71.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hasktags-0.71.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hasktags-0.71.2
hs-libraries: HShasktags-0.71.2-1gORn2EhZbaCrvadY9CSJo
depends:
    base-4.12.0.0 bytestring-0.10.8.2 directory-1.3.3.0
    filepath-1.4.2.1 json-0.9.3-KMo6fueTh6fHhtSWtpDb75
    microlens-platform-0.4.0-ZyMWxEzL09JA6MSSLDktz
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/hasktags/html/hasktags.haddock
haddock-html: /usr/share/doc/hasktags/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
